@@ -1,7 +1,7 @@
 /**
  * gui.c - GUI code for SciteProj
  *
- *  Copyright 2006 Roy Wood, 2009-2017 Andreas Rönnquist
+ *  Copyright 2006 Roy Wood, 2009-2018 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  *
@@ -749,9 +749,9 @@ static void tree_row_activated_cb(GtkTreeView *treeView,
 		goto EXITPOINT;
 	}
 
-	absFilePath=fix_path((gchar*)get_project_directory(), relFilePath);
+	absFilePath = fix_path((gchar*)get_project_directory(), relFilePath);
 
-	fixed=fix_path((gchar*)get_project_directory(), relFilePath);
+	fixed = fix_path((gchar*)get_project_directory(), relFilePath);
 
 	if ((command = g_strdup_printf("open:%s\n", fixed)) == NULL) {
 		g_set_error(&err, APP_SCITEPROJ_ERROR, -1,
@@ -765,7 +765,7 @@ static void tree_row_activated_cb(GtkTreeView *treeView,
 
 			activate_scite(NULL);
 
-			if (prefs.give_scite_focus==TRUE) {
+			if (prefs.give_scite_focus == TRUE) {
 				send_scite_command((gchar*)"focus:0", NULL);
 			}
 
@@ -1005,4 +1005,14 @@ void recent_files_switch_visible()
 void set_dialog_transient(GtkWidget *dialog)
 {
 	gtk_window_set_transient_for(GTK_WINDOW(dialog), GTK_WINDOW(sMainWindow));
-}
\ No newline at end of file
+}
+
+
+/**
+ *
+ */
+GtkWindow *get_main_window()
+{
+	return GTK_WINDOW(sMainWindow);
+}
+
