@@ -85,20 +85,20 @@ gchar *default_config_string = (gchar*)"" \
 gboolean check_config_string(gchar *in_config)
 {
 	gboolean result = FALSE;
-	int co=0;
+	int co = 0;
 	gdouble tempdouble;
 
 	gchar *tempstring = NULL;
 
-	int pos=-1;
+	int pos = -1;
 
-	gchar *value=in_config;
+	gchar *value = in_config;
 
 	// clear scite Path
 
 	prefs.scite_path = NULL;
 
-	for (co=0; co < (int)strlen(in_config); co++) {
+	for (co = 0; co < (int)strlen(in_config); co++) {
 		if (in_config[co] == '=') pos=co;
 
 		if (pos == -1) {
@@ -119,34 +119,34 @@ gboolean check_config_string(gchar *in_config)
 		value = g_strchug(value);
 		value = g_strchomp(value);
 
-		if (g_ascii_strcasecmp(tempstring, "xpos")==0) {
+		if (g_ascii_strcasecmp(tempstring, "xpos") == 0) {
 			tempdouble = g_ascii_strtod(value, NULL);
 			prefs.xpos = (int) tempdouble;
 		}
 
-		if (g_ascii_strcasecmp(tempstring, "ypos")==0) {
+		if (g_ascii_strcasecmp(tempstring, "ypos") == 0) {
 			tempdouble = g_ascii_strtod(value, NULL);
 			prefs.ypos = (int)tempdouble;
 		}
 
-		if (g_ascii_strcasecmp(tempstring, "width")==0) {
+		if (g_ascii_strcasecmp(tempstring, "width") == 0) {
 			tempdouble = g_ascii_strtod(value, NULL);
 			prefs.width = (int)tempdouble;
 		}
 
-		if (g_ascii_strcasecmp(tempstring, "height")==0) {
+		if (g_ascii_strcasecmp(tempstring, "height") == 0) {
 			tempdouble = g_ascii_strtod(value, NULL);
 			prefs.height = (int)tempdouble;
 		}
 
-		if (g_ascii_strcasecmp(tempstring, "give_scite_focus")==0) {
-			if (g_ascii_strcasecmp(value, "TRUE")==0) {
+		if (g_ascii_strcasecmp(tempstring, "give_scite_focus") == 0) {
+			if (g_ascii_strcasecmp(value, "TRUE") == 0) {
 				prefs.give_scite_focus = TRUE;
 			}
 		}
 
 
-		if (g_ascii_strcasecmp(tempstring, "scite_path")==0) {
+		if (g_ascii_strcasecmp(tempstring, "scite_path") == 0) {
 			prefs.scite_path = g_strdup_printf("%s", value);
 		}
 
@@ -156,7 +156,7 @@ gboolean check_config_string(gchar *in_config)
 			}
 		}
 
-		if (g_ascii_strcasecmp(tempstring, "recent_add_to_bottom")==0) {
+		if (g_ascii_strcasecmp(tempstring, "recent_add_to_bottom") == 0) {
 			if (g_ascii_strcasecmp(value, "TRUE") == 0) {
 				prefs.recent_add_to_bottom = TRUE;
 			}
@@ -217,7 +217,7 @@ gboolean init_prefs(gchar *target_directory, GError **err)
 
 	// First, check the file ~/.config/sciteprojrc.lua
 
-	gchar *test_prefs_filename = g_build_filename(g_get_user_config_dir(), "sciteprojrc.lua",NULL);
+	gchar *test_prefs_filename = g_build_filename(g_get_user_config_dir(), "sciteprojrc.lua", NULL);
 
 	if (g_file_test(test_prefs_filename, G_FILE_TEST_IS_REGULAR)) {
 
@@ -246,7 +246,7 @@ gboolean init_prefs(gchar *target_directory, GError **err)
 
 		// the result of g_get_user_config_dir doesn't need to be freed, so we
 		// dont need to put it in a pointer of its own.
-		prefs_filename = g_build_filename(g_get_user_config_dir(), "sciteprojrc",NULL);
+		prefs_filename = g_build_filename(g_get_user_config_dir(), "sciteprojrc", NULL);
 
 		// Check if a config-file exists
 		if (!g_file_test(prefs_filename, G_FILE_TEST_IS_REGULAR)) {
@@ -278,7 +278,7 @@ gboolean init_prefs(gchar *target_directory, GError **err)
 	// Check if it is an old-style config, or a new LUA one
 	if (check_for_old_style_config(config_string)) {
 
-		gchar **savedlist = NULL;
+		gchar **savedlist;
 
 		debug_printf("Old style config\n");
 		// split out the lines, and add each to the list of strings
@@ -294,7 +294,7 @@ gboolean init_prefs(gchar *target_directory, GError **err)
 
 			if (temp != NULL) {
 
-				if ((temp[0] != '#') && (strcmp(temp, "")!=0)) {
+				if ((temp[0] != '#') && (strcmp(temp, "") != 0)) {
 					// We got a valid string:
 					// no starting #, and not an empty string.
 
@@ -312,7 +312,7 @@ gboolean init_prefs(gchar *target_directory, GError **err)
 
 
 		//if (!load_lua_config(config_string)) {
-		if (load_lua_config(prefs_filename, config_string)!=0) {
+		if (load_lua_config(prefs_filename, config_string) != 0) {
 			printf("error loading LUA config!\n");
 		}
 	}
@@ -355,7 +355,7 @@ gboolean check_for_old_style_config(const gchar *teststring)
 	// Another way to check is to check for lines starting with # - as a comment
 	// LUA uses "--", so this is should work to identify oldstyle config.
 
-	for (co=0; co<strlen(teststring); co++) {
+	for (co = 0; co < strlen(teststring); co++) {
 		if (teststring[co] == '\n') {
 			//printf("Tecken: %c\n", teststring[co+1]);
 
@@ -378,7 +378,7 @@ int load_lua_config(gchar *filename, gchar *full_string)
 	lua = init_script();
 
 	//if (load_script_buffer(lua, config_string)!=0) {
-	if (load_script_buffer(lua, full_string)!=0) {
+	if (load_script_buffer(lua, full_string) != 0) {
 		printf("Error loading file: %s\n", filename);
 		return FALSE;
 	}
