@@ -1,7 +1,7 @@
 /**
  * recent_files.c - list of recently opened files
  *
- *  Copyright 2011-2017 Andreas Rönnquist
+ *  Copyright 2011-2018 Andreas Rönnquist
  *
  * This file is part of SciteProj.
  *
@@ -311,7 +311,7 @@ gboolean add_file_to_recent(gchar *filepath, GError **err)
 		++fileExt;
 	}
 
-	if (fileExt == NULL || strlen(fileExt) <= 0) {
+	if (fileExt == NULL || (int)strlen(fileExt) <= 0) {
 		fileExt = (gchar*)fileName;
 	}
 
